==> haskell-geniplate-mirror-0.7.8-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-geniplate-mirror.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 geniplate-mirror
version:              0.7.8
visibility:           public
id:                   geniplate-mirror-0.7.8-6RSxlnEk5b3Af8Gn26wDnH
key:                  geniplate-mirror-0.7.8-6RSxlnEk5b3Af8Gn26wDnH
license:              BSD-3-Clause
copyright:            2014-2015 Lennart Augustsson
maintainer:
    Dan Rosén <dan.rosen@gu.se>, Liang-Ting Chen <liang.ting.chen.tw@gmail.com>

author:               Lennart Augustsson
stability:            experimental
homepage:             https://github.com/danr/geniplate
synopsis:             Use Template Haskell to generate Uniplate-like functions.
description:
    Use Template Haskell to generate Uniplate-like functions.

    This is a maintained mirror of the
    <http://hackage.haskell.org/package/geniplate geniplate> package,
    written by Lennart Augustsson.

category:             Generics
abi:                  c02526eae3ef8408b73bf04e0058cf4f
exposed:              True
exposed-modules:      Data.Generics.Geniplate
import-dirs:          /usr/lib/ghc-9.0.1/site-local/geniplate-mirror-0.7.8
library-dirs:         /usr/lib/ghc-9.0.1/site-local/geniplate-mirror-0.7.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/geniplate-mirror-0.7.8
hs-libraries:         HSgeniplate-mirror-0.7.8-6RSxlnEk5b3Af8Gn26wDnH
depends:              base-4.15.0.0 mtl-2.2.2 template-haskell-2.17.0.0
haddock-interfaces:
    /usr/share/doc/haskell-geniplate-mirror/html/geniplate-mirror.haddock

haddock-html:         /usr/share/doc/haskell-geniplate-mirror/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-geniplate-mirror-0.7.8-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-geniplate-mirror.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 geniplate-mirror
version:              0.7.8
visibility:           public
id:                   geniplate-mirror-0.7.8-DL9Bt8lQhUJ4CtLweYsrjf
key:                  geniplate-mirror-0.7.8-DL9Bt8lQhUJ4CtLweYsrjf
license:              BSD-3-Clause
copyright:            2014-2015 Lennart Augustsson
maintainer:
    Dan Rosén <dan.rosen@gu.se>, Liang-Ting Chen <liang.ting.chen.tw@gmail.com>

author:               Lennart Augustsson
stability:            experimental
homepage:             https://github.com/danr/geniplate
synopsis:             Use Template Haskell to generate Uniplate-like functions.
description:
    Use Template Haskell to generate Uniplate-like functions.

    This is a maintained mirror of the
    <http://hackage.haskell.org/package/geniplate geniplate> package,
    written by Lennart Augustsson.

category:             Generics
abi:                  29a39ba0ae7797cb13c68b4e758ec74c
exposed:              True
exposed-modules:      Data.Generics.Geniplate
import-dirs:          /usr/lib/ghc-9.0.2/site-local/geniplate-mirror-0.7.8
library-dirs:         /usr/lib/ghc-9.0.2/site-local/geniplate-mirror-0.7.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/geniplate-mirror-0.7.8
hs-libraries:         HSgeniplate-mirror-0.7.8-DL9Bt8lQhUJ4CtLweYsrjf
depends:              base-4.15.1.0 mtl-2.2.2 template-haskell-2.17.0.0
haddock-interfaces:
    /usr/share/doc/haskell-geniplate-mirror/html/geniplate-mirror.haddock

haddock-html:         /usr/share/doc/haskell-geniplate-mirror/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
